<template>
    <v-card elevation="3">
        <Head title="Slider"/>
        <v-card-title class="subtitle-1">
            Create a new slider
        </v-card-title>
        <v-divider/>
        <v-card-text>
            <v-form class="mt-3">
                <v-row>

                    <v-col cols="12">
                        <v-text-field label="Name" v-model="form.name" :loading="loading"
                                      :error-messages="error.name" hide-details
                                      outlined dense></v-text-field>
                    </v-col>

                    <v-col cols="12">
                        <v-text-field label="Title" v-model="form.title" :loading="loading"
                                      :error-messages="error.title" hide-details
                                      outlined dense></v-text-field>
                    </v-col>

                    <v-col cols="12">
                        <v-text-field label="Subtitle" v-model="form.subtitle" :loading="loading"
                                      :error-messages="error.subtitle" hide-details
                                      outlined dense></v-text-field>
                    </v-col>

                    <v-col cols="12">
                        <v-textarea label="Description" v-model="form.description" auto-grow :loading="loading"
                                      :error-messages="error.description" hide-details outlined dense></v-textarea>
                    </v-col>

                    <v-col cols="12">
                        <v-text-field label="Background colour" v-model="form.background_colour" :loading="loading"
                                      :error-messages="error.background_colour" hide-details outlined dense></v-text-field>
                    </v-col>

                    <v-col cols="6">
                        <v-text-field label="Action button text" v-model="form.action_button_text" :loading="loading"
                                      :error-messages="error.action_button_text" hide-details outlined dense></v-text-field>
                    </v-col>

                    <v-col cols="6">
                        <v-text-field label="Colour" v-model="form.action_button_colour" :loading="loading"
                                      :error-messages="error.action_button_colour" hide-details outlined dense></v-text-field>
                    </v-col>

                    <v-col cols="6">
                        <v-text-field label="Video URL" v-model="form.video_url" :loading="loading"
                                      :error-messages="error.video_url" hide-details outlined dense></v-text-field>
                    </v-col>

                    <v-col>
                        <v-text-field label="Photo" v-model="form.photo.label" outline dense
                                      placeholder="Paste URL or click Browse" hide-details>
                            <v-btn @click="selectPhoto" text slot="append" dense v-if="!form.photo.id">
                                Browse <v-icon right color="primary">mdi-folder-open</v-icon>
                            </v-btn>
                            <v-btn @click="form.photo = {}" text slot="append" dense v-else>
                                Remove <v-icon right color="error">mdi-delete</v-icon>
                            </v-btn>
                        </v-text-field>
                    </v-col>
                </v-row>
            </v-form>
            <v-divider/>
        </v-card-text>
        <v-card-actions>
            <v-row>
                <v-spacer/>
                <v-col align="end">
                    <v-btn class="" text small :loading="loading" @click="storeSlider" color="primary">
                        Save
                        <v-icon right>mdi-content-save-outline</v-icon>
                    </v-btn>
                </v-col>
            </v-row>
        </v-card-actions>
    </v-card>
</template>

<script>
import Settings from "../../../Components/Layouts/Settings.vue";
import Setting from "../Setting.vue";
import Site from "./Site.vue";

export default {
    name: "CreateSlider",
    layout: [Settings, Setting, Site],
    props: {},
    data() {
        return {
            loading: false,
            error: {
                name: [],
                title: [],
                subtitle: [],
                description: [],
                photo: [],
                background_colour: [],
                action_button_text: [],
                action_button_colour: [],
                video_url: [],
            },
            form: {
                name: '',
                title: '',
                subtitle: '',
                description: '',
                photo: {},
                background_colour: '',
                action_button_text: '',
                action_button_colour: '',
                video_url: ''
            },
            eventSubscription: null
        }
    },
    methods: {
        clearError() {
            for (let i in this.error) {
                this.error[i] = []
            }
        },
        storeSlider() {
            this.$inertia.post(this.$route('user.store'), this.form, {
                onBefore: () => {
                    this.loading = true
                },
                onSuccess: (page) => {
                    this.showSnack(["Successfully saved new member!"])
                },
                onError: (errors) => {
                    if (errors && Object.values(errors).length) {
                        this.showSnack([Object.values(errors)[0], "error"])
                    }
                },
                onFinish: visit => {
                    this.loading = false
                },
            });
        },
        selectPhoto() {
            let eventName = 'landlord-profilexxx'
            this.eventSubscription = this.$store.subscribe((mutation, state) => {
                if (mutation.type === "Media/SET_EVENT_NAME" && mutation.payload === eventName) {
                    if (state.Media.media.length) {
                        this.form.photo = state.Media.media[0]
                        this.eventSubscription()
                    }
                }
            });
            this.showMediaDialog({event: eventName, type: 'image'})
        }
    },
    mounted() {
    }
}
</script>

<style>

</style>
